@@ -1,7 +1,7 @@
 package File::Which::Patch::Hide;
 
-our $DATE = '2016-05-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-07-01'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ my $w_which = sub {
     my @filtered_res;
     for my $path (@res) {
         my ($vol, $dir, $file) = File::Spec->splitpath($path);
-        next if grep { $file eq $_ } @prog;
+        next if grep { m![/\\]! ? $path eq $_ : $file eq $_ } @prog;
         push @filtered_res, $path;
     }
 
@@ -80,14 +80,19 @@ File::Which::Patch::Hide - Hide some programs from File::Which
 
 =head1 VERSION
 
-This document describes version 0.002 of File::Which::Patch::Hide (from Perl distribution File-Which-Patch-Hide), released on 2016-05-22.
+This document describes version 0.003 of File::Which::Patch::Hide (from Perl distribution File-Which-Patch-Hide), released on 2016-07-01.
 
 =head1 SYNOPSIS
 
  % PERL5OPT=-MFile::Which::Patch::Hide=-prog,'foo;bar' app.pl
 
-C<app.pl> will think that C<foo> and C<bar> are not in C<PATH> even though they
-actually are.
+In the above example C<app.pl> will think that C<foo> and C<bar> are not in
+C<PATH> even though they actually are.
+
+ % PERL5OPT=-MFile::Which::Patch::Hide=-prog,'/usr/bin/foo' app.pl
+
+The above example hides just C</usr/bin/foo> but C<foo> might be available in
+another directory in PATH.
 
 =head1 DESCRIPTION
 
